==> hazelcast-all-3.0-RC1-sources.jar: com/hazelcast/queue/proxy/QueueIterator.java <==
/*
 * Copyright (c) 2008-2013, Hazelcast, Inc. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.hazelcast.queue.proxy;

import com.hazelcast.nio.serialization.Data;
import com.hazelcast.nio.serialization.SerializationService;

import java.util.Iterator;

/**
 * @ali 12/18/12
 */
public class QueueIterator<E> implements Iterator<E> {

    final Iterator<Data> iter;
    final SerializationService serializationService;

    final boolean binary;

    public QueueIterator(Iterator<Data> iter, SerializationService serializationService, boolean binary) {
        this.iter = iter;
        this.serializationService = serializationService;
        this.binary = binary;
    }

    public boolean hasNext() {
        return iter.hasNext();
    }

    public E next() {
        Data data = iter.next();
        if (binary) {
            return (E) data;
        }
        return (E) serializationService.toObject(data);
    }

    public void remove() {
        iter.remove();
    }
}

==> hazelcast-all-3.3-RC1-sources.jar: com/hazelcast/queue/proxy/QueueIterator.java <==
/*
 * Copyright (c) 2008-2013, Hazelcast, Inc. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.hazelcast.queue.proxy;

import com.hazelcast.nio.serialization.Data;
import com.hazelcast.nio.serialization.SerializationService;

import java.util.Iterator;

/**
 * Iterator for the Queue.
 * @param <E>
 */
public class QueueIterator<E> implements Iterator<E> {

    private final Iterator<Data> iterator;
    private final SerializationService serializationService;
    private final boolean binary;

    public QueueIterator(Iterator<Data> iterator, SerializationService serializationService, boolean binary) {
        this.iterator = iterator;
        this.serializationService = serializationService;
        this.binary = binary;
    }

    @Override
    public boolean hasNext() {
        return iterator.hasNext();
    }

    @Override
    public E next() {
        Data data = iterator.next();
        if (binary) {
            return (E) data;
        }
        return (E) serializationService.toObject(data);
    }

    @Override
    public void remove() {
        iterator.remove();
    }
}
